@@ -12,6 +12,7 @@ from urllib.parse import urlparse
 from datetime import datetime
 import subprocess
 import shlex
+import shutil
 
 # shortcuts:
 # sail profile .profiles/some-file.json
@@ -22,6 +23,7 @@ import shlex
 # sail profile curl -H 'Some: header' -XPOST https://example.org
 # sail profile key --curl
 # sail profile download /var/www/profiles/filename.xhprof
+# sail profile clean
 
 class ProfilerCmd(click.Group):
 	def resolve_command(self, ctx, args):
@@ -135,7 +137,7 @@ def run(ctx, url):
 		raise click.ClickException('Profile key not found in .sail/config.json')
 
 	url = urlparse(url)
-	host = '%s.sailed.io' % sail_config['app_id']
+	host = sail_config['hostname']
 	query = url.query
 	nocache = 'SAIL_NO_CACHE=%d' % time.time()
 	query = nocache if not query else query + '&' + nocache
@@ -233,7 +235,7 @@ def download(path):
 	click.echo('- Downloading profile from %s' % path)
 
 	args = ['-t']
-	source = 'root@%s.sailed.io:%s' % (sail_config['app_id'], path)
+	source = 'root@%s:%s' % (sail_config['hostname'], path)
 	destination = '%s/%s' % (profiles_dir, dest_filename)
 	returncode, stdout, stderr = util.rsync(args, source, destination, default_filters=False)
 
@@ -247,7 +249,7 @@ def download(path):
 		'-o', 'UserKnownHostsFile=%s/.sail/known_hosts' % root,
 		'-o', 'IdentitiesOnly=yes',
 		'-o', 'IdentityFile=%s/.sail/ssh.key' % root,
-		'root@%s.sailed.io' % sail_config['app_id'],
+		'root@%s' % sail_config['hostname'],
 		'rm %s' % path
 	])
 
@@ -260,6 +262,36 @@ def download(path):
 	click.echo('- Profile saved to .profiles/%s' % dest_filename)
 	return profiles_dir / dest_filename
 
+@profile.command()
+def clean():
+	'''Delete all profiling data from production and local working copy'''
+	root = util.find_root()
+	sail_config = util.get_sail_config()
+
+	# Delete local profiles
+	click.echo('# Cleaning up')
+	click.echo('- Deleting local profiles')
+	profiles_dir = pathlib.Path(root + '/.profiles')
+	shutil.rmtree(profiles_dir)
+
+	click.echo('- Deleting production profiles')
+	p = subprocess.Popen(['ssh',
+		'-i', '%s/.sail/ssh.key' % root,
+		'-o', 'UserKnownHostsFile=%s/.sail/known_hosts' % root,
+		'-o', 'IdentitiesOnly=yes',
+		'-o', 'IdentityFile=%s/.sail/ssh.key' % root,
+		'root@%s' % sail_config['hostname'],
+		'rm -rf /var/www/profiles/*'
+	])
+
+	while p.poll() is None:
+		util.loader()
+
+	if p.returncode != 0:
+		raise click.ClickException('An error occurred in SSH. Please try again.')
+
+	click.echo('- Done')
+
 def _render_summary(pad, totals):
 	run_id = datetime.fromtimestamp(totals['timestamp']).strftime('%Y-%m-%d %H:%M:%S')
 
@@ -290,8 +322,14 @@ def _render_summary(pad, totals):
 	pad.addstr(' HTTP Reqs: ', curses.color_pair(1))
 	pad.addstr('{:,}'.format(totals['http_reqs']), curses.color_pair(2))
 
-def _render_listview(pad, columns, data, cols, selected = 0):
+def _render_listview(pad, columns, data, cols, selected=0, lines=None):
 	y = -1
+
+	if lines:
+		offset_y, visible = lines
+		y += offset_y
+		data = data[offset_y:visible+1]
+
 	for entry in data:
 		y += 1
 
@@ -470,11 +508,12 @@ def _render_view_symbol(stdscr, data, totals, symbol, selected=1, sort=2):
 			offset_y = selected - 1
 
 		if refresh:
-			_render_listview(listview, columns, listview_data, cols, selected)
-			listview.refresh(offset_y,0, 4,0, rows - 2, cols - 1)
+			lines = (offset_y, offset_y + visible)
+			_render_listview(listview, columns, listview_data, cols, selected, lines)
+			listview.refresh(offset_y,0, 4,0, rows-2,cols-1)
 
 			_render_sticky_header(sticky_header, columns, listview_data, cols, offset_y)
-			sticky_header.refresh(0,0, 4,0, 6, cols -1)
+			sticky_header.refresh(0,0, 4,0, 6,cols-1)
 
 			_render_footer(footer, selected, len(listview_data), cols)
 			footer.refresh(0,0, rows-1,0, rows-1,cols-1)
@@ -563,7 +602,8 @@ def _render_view_main(stdscr, data, totals, selected=1, sort=2):
 			offset_y = selected - 1
 
 		if refresh:
-			_render_listview(listview, columns, listview_data, cols, selected)
+			lines = (offset_y, offset_y + visible)
+			_render_listview(listview, columns, listview_data, cols, selected, lines)
 			listview.refresh(offset_y,0, 4,0, rows-2,cols-1)
 
 			_render_sticky_header(sticky_header, columns, listview_data, cols, offset_y)
